==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/lyrics/translations/lyrics_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>察看歌詞</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>歌詞插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>關於歌詞插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp 歌詞插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
        <translation>此插件歌詞來自於 lyricsplugin.com</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.cpp" line="113"/>
        <source>Lyrics: %1 - %2</source>
        <translation>歌詞：%1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="88"/>
        <location filename="../lyricswindow.ui" line="67"/>
        <source>No connection</source>
        <translation>無連接</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="75"/>
        <source>Not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="91"/>
        <source>Looking up host...</source>
        <translation>找尋主機...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="94"/>
        <source>Connecting...</source>
        <translation>連接...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="97"/>
        <source>Sending request...</source>
        <translation>發送請求...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="100"/>
        <source>Receiving</source>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="103"/>
        <source>Connected</source>
        <translation>已連接</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="106"/>
        <source>Closing connection...</source>
        <translation>關閉連接...</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>歌詞插件</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>藝術家：</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>標題：</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="87"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
</TS>

==> qmmp_0.4.1.orig.tar.gz: qmmp-0.4.1/src/plugins/General/lyrics/translations/lyrics_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>察看歌詞</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>歌詞插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>關於歌詞插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp 歌詞插件</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
        <translation>此插件歌詞來自於 lyricsplugin.com</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.cpp" line="63"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="97"/>
        <source>Lyrics: %1 - %2</source>
        <translation>歌詞：%1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>無連接</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="85"/>
        <source>Not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="96"/>
        <source>Receiving</source>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>歌詞插件</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>藝術家：</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>標題：</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
</TS>
